# -*- coding: utf-8 -*-
'''
>>> import coverage
>>> from opem.Static.Amphlett import *
>>> import random
>>> cov=coverage.Coverage()
>>> cov.start()
>>> isfloat("2")
True
>>> isfloat("2.02")
True
>>> isfloat('ss')
False
>>> filter_lambda({"lambda":24})
[Warning] Opem Automatically Set Lambda To Maximum Value (23)
{'lambda': 23}
>>> filter_alpha({"alpha":2})
[Warning] Opem Automatically Set Alpha To Maximum Value (1)
{'alpha': 1}
>>> filter_lambda({"lambda":13})
[Warning] Opem Automatically Set Lambda To Minimum Value (14)
{'lambda': 23}
>>> filter_alpha({"alpha":-0.1})
[Warning] Opem Automatically Set Alpha To Maximum Value (0)
{'alpha': 0}
>>> T=343.15
>>> PH2=1
>>> PO2=1
>>> i=0
>>> A=50.6
>>> l=0.178
>>> lambda_param=23
>>> N=1
>>> Jn=0.003
>>> JMax=0.469
>>> Enernst_Calc(T,PH2,PO2)
1.19075
>>> CH2_Calc(PH2,T)
7.330294784824117e-07
>>> CO2_Calc(PO2,T)
8.402541445801334e-07
>>> Rho_Calc(i,A,T,lambda_param)
4.978789826264977
>>> Xi2_Calc(A,PH2,T)
0.0030373688787134006
>>> Eta_Conc_Calc(i,A,Jn,JMax)
0
>>> Eta_Ohmic_Calc(i,l,A,T,lambda_param)
0
>>> Eta_Act_Calc(T,PO2,PH2,i,A)
0
>>> PowerStack_Calc(2,2)
4
>>> PowerStack_Calc(None,2)
[Error] Power Stack Calculation Error (Power:None, N:2)
>>> T='20000000000'
>>> PH2='10000000'
>>> PO2='1000000000'
>>> i='160000000'
>>> A='30000000000'
>>> l='50000000000'
>>> lambda_param='50000000000'
>>> N='80000000000'
>>> Enernst_Calc(T,PH2,PO2)
[Error] Enernst Calculation Failed (T:20000000000 , PH2:10000000, PO2:1000000000)
>>> CH2_Calc(PH2,T)
[Error] CH2 Calculation Failed (PH2:10000000, T:20000000000)
>>> CO2_Calc(PO2,T)
[Error] CO2 Calculation Failed (PO2:1000000000, T:20000000000)
>>> Rho_Calc(i,A,T,lambda_param)
[Error] Rho Calculation Failed (i:160000000, A:30000000000, T:20000000000, lambda:50000000000)
>>> Xi2_Calc(A,PH2,T)
[Error] CH2 Calculation Failed (PH2:10000000, T:20000000000)
[Error] Xi2 Calculation Failed (A:30000000000, PH2:10000000, T:20000000000)
>>> Eta_Conc_Calc(i,A,None,None)
[Error] Eta Concentration Calculation Failed (i:160000000, A:30000000000, B:None, JMax:None)
>>> Eta_Ohmic_Calc(i,l,A,T,lambda_param)
[Error] Rho Calculation Failed (i:160000000, A:30000000000, T:20000000000, lambda:50000000000)
[Error] Eta Ohmic Calculation Failed (i:160000000, l:50000000000, A:30000000000, T:20000000000, lambda:50000000000, R_elec:None)
>>> Eta_Act_Calc(T,PO2,PH2,i,A)
[Error] CO2 Calculation Failed (PO2:1000000000, T:20000000000)
[Error] CH2 Calculation Failed (PH2:10000000, T:20000000000)
[Error] Xi2 Calculation Failed (A:30000000000, PH2:10000000, T:20000000000)
[Error] Eta Activation Calculation Failed (T:20000000000, PO2:1000000000, PH2:10000000, i:160000000, A:30000000000)
>>> Efficiency_Calc(None)
[Error] PEM Efficiency Calculation Failed (Vcell:None)
>>> VStack_Calc(12,None)
[Error] VStack Calculation Error (N:12, Vcell:None)
>>> Amphlett_Data=Static_Analysis(InputMethod={},TestMode=True)
###########
Amphlett-Model Simulation
###########
Analyzing . . .
[Error] Amphlett Simulation Failed!(Check Your Inputs)
>>> Loss_Calc(122,22,None)
[Error] Loss Calculation Error (Eta_Act:122, Eta_Ohmic:22, Eta_Conc:None)
>>> Vcell_Calc(122,None)
[Error] Vcell Calculation Error (Enernst:122, Loss:None)
>>> Vcell_Calc(122,None)
[Error] Vcell Calculation Error (Enernst:122, Loss:None)
>>> Test_Vector={"T":343.15,"PH2":1,"PO2":1,"i-start":0,"i-stop":4,"i-step":0.1,"A":50.6,"l":0.0178,"lambda":23,"N":1,"R":0,"JMax":1.5,"B":0.016,"Name":"test1"}
>>> Amphlett_Data=Static_Analysis(InputMethod=Test_Vector,TestMode=True)
###########
Amphlett-Model Simulation
###########
Analyzing . . .
I : 0
Enernst : 1.19075 V
Eta Activation : 0 V
Eta Concentration : 0 V
Eta Ohmic : 0 V
Loss : 0 V
PEM Efficiency : 0.763301282051282
Power : 0.0 W
Power-Stack : 0.0 W
VStack : 1.19075 V
Vcell : 1.19075 V
###########
I : 0.1
Enernst : 1.19075 V
Eta Activation : 0.11807074742083559 V
Eta Concentration : 2.109426805213159e-05 V
Eta Ohmic : 0.00017520002843124318 V
Loss : 0.11826704171731897 V
PEM Efficiency : 0.6874890758222313
Power : 0.1072482958282681 W
Power-Stack : 0.1072482958282681 W
VStack : 1.072482958282681 V
Vcell : 1.072482958282681 V
###########
I : 0.2
Enernst : 1.19075 V
Eta Activation : 0.1639764642376006 V
Eta Concentration : 4.221638333089875e-05 V
Eta Ohmic : 0.0003505137928660484 V
Loss : 0.16436919441379755 V
PEM Efficiency : 0.6579364138373093
Power : 0.2052761611172405 W
Power-Stack : 0.2052761611172405 W
VStack : 1.0263808055862025 V
Vcell : 1.0263808055862025 V
###########
I : 0.3
Enernst : 1.19075 V
Eta Activation : 0.1908295871441327 V
Eta Concentration : 6.336641945755048e-05 V
Eta Ohmic : 0.0005259414221215358 V
Loss : 0.1914188949857118 V
PEM Efficiency : 0.6405968621886462
Power : 0.29979933150428645 W
Power-Stack : 0.29979933150428645 W
VStack : 0.9993311050142881 V
Vcell : 0.9993311050142881 V
###########
I : 0.4
Enernst : 1.19075 V
Eta Activation : 0.20988218105436562 V
Eta Concentration : 8.454445034568427e-05 V
Eta Ohmic : 0.0007014830568214833 V
Loss : 0.21066820856153282 V
PEM Efficiency : 0.628257558614402
Power : 0.3920327165753869 W
Power-Stack : 0.3920327165753869 W
VStack : 0.9800817914384672 V
Vcell : 0.9800817914384672 V
###########
I : 0.5
Enernst : 1.19075 V
Eta Activation : 0.22466052101362555 V
Eta Concentration : 0.00010575055020278165 V
Eta Ohmic : 0.0008771388470514419 V
Loss : 0.22564341041087976 V
PEM Efficiency : 0.618658070249436
Power : 0.4825532947945601 W
Power-Stack : 0.4825532947945601 W
VStack : 0.9651065895891202 V
Vcell : 0.9651065895891202 V
###########
I : 0.6
Enernst : 1.19075 V
Eta Activation : 0.23673530396089773 V
Eta Concentration : 0.00012698479353178086 V
Eta Ohmic : 0.0010529089510685316 V
Loss : 0.23791519770549804 V
PEM Efficiency : 0.610791539932373
Power : 0.5717008813767012 W
Power-Stack : 0.5717008813767012 W
VStack : 0.9528348022945019 V
Vcell : 0.9528348022945019 V
###########
I : 0.7
Enernst : 1.19075 V
Eta Activation : 0.2469443874769634 V
Eta Concentration : 0.000148247255132642 V
Eta Ohmic : 0.001228793534444728 V
Loss : 0.24832142826654077 V
PEM Efficiency : 0.60412087931632
Power : 0.6597000002134213 W
Power-Stack : 0.6597000002134213 W
VStack : 0.9424285717334592 V
Vcell : 0.9424285717334592 V
###########
I : 0.8
Enernst : 1.19075 V
Eta Activation : 0.25578789787113065 V
Eta Concentration : 0.00016953801010392253 V
Eta Ohmic : 0.0014047927694433354 V
Loss : 0.2573622286506779 V
PEM Efficiency : 0.5983254944546936
Power : 0.7467102170794577 W
Power-Stack : 0.7467102170794577 W
VStack : 0.933387771349322 V
Vcell : 0.933387771349322 V
###########
I : 0.9
Enernst : 1.19075 V
Eta Activation : 0.26358842686742984 V
Eta Concentration : 0.00019085713384438152 V
Eta Ohmic : 0.0015809068345387157 V
Loss : 0.2653601908358129 V
PEM Efficiency : 0.5931985956180685
Power : 0.8328508282477683 W
Power-Stack : 0.8328508282477683 W
VStack : 0.925389809164187 V
Vcell : 0.925389809164187 V
###########
I : 1.0
Enernst : 1.19075 V
Eta Activation : 0.2705662378303906 V
Eta Concentration : 0.00021220470205456714 V
Eta Ohmic : 0.0017571359140316743 V
Loss : 0.2725355784464768 V
PEM Efficiency : 0.5885989881753353
Power : 0.9182144215535232 W
Power-Stack : 0.9182144215535232 W
VStack : 0.9182144215535232 V
Vcell : 0.9182144215535232 V
###########
I : 1.1
Enernst : 1.19075 V
Eta Activation : 0.27687843565296244 V
Eta Concentration : 0.0002335807907384422 V
Eta Ohmic : 0.001933480197732536 V
Loss : 0.2790454966414334 V
PEM Efficiency : 0.5844259636913888
Power : 1.0028749536944233 W
Power-Stack : 1.0028749536944233 W
VStack : 0.9117045033585666 V
Vcell : 0.9117045033585666 V
###########
I : 1.2
Enernst : 1.19075 V
Eta Activation : 0.28264102077766273 V
Eta Concentration : 0.00025498547620500224 V
Eta Ohmic : 0.002109939880694226 V
Loss : 0.285005946134562 V
PEM Efficiency : 0.5806051627342551
Power : 1.0868928646385256 W
Power-Stack : 1.0868928646385256 W
VStack : 0.905744053865438 V
Vcell : 0.905744053865438 V
###########
I : 1.3
Enernst : 1.19075 V
Eta Activation : 0.28794208521933035 V
Eta Concentration : 0.0002764188350699048 V
Eta Ohmic : 0.002286515162983545 V
Loss : 0.2905050192173838 V
PEM Efficiency : 0.5770801158862924
Power : 1.1703184750174012 W
Power-Stack : 1.1703184750174012 W
VStack : 0.9002449807826162 V
Vcell : 0.9002449807826162 V
###########
I : 1.4
Enernst : 1.19075 V
Eta Activation : 0.29285010429372843 V
Eta Concentration : 0.00029788094425712723 V
Eta Ohmic : 0.0024632062494824017 V
Loss : 0.29561119148746795 V
PEM Efficiency : 0.5738069285336743
Power : 1.2531943319175447 W
Power-Stack : 1.2531943319175447 W
VStack : 0.895138808512532 V
Vcell : 0.895138808512532 V
###########
I : 1.5
Enernst : 1.19075 V
Eta Activation : 0.29741936073692266 V
Eta Concentration : 0.00031937188100060893 V
Eta Ohmic : 0.002640013349713048 V
Loss : 0.3003787459676363 V
PEM Efficiency : 0.5707508038668997
Power : 1.3355568810485454 W
Power-Stack : 1.3355568810485454 W
VStack : 0.8903712540323636 V
Vcell : 0.8903712540323636 V
###########
I : 1.6
Enernst : 1.19075 V
Eta Activation : 0.3016936146878957 V
Eta Concentration : 0.0003408917228459314 V
Eta Ohmic : 0.0028169366776829123 V
Loss : 0.3048514430884245 V
PEM Efficiency : 0.567883690327933
Power : 1.417437691058521 W
Power-Stack : 1.417437691058521 W
VStack : 0.8858985569115755 V
Vcell : 0.8858985569115755 V
###########
I : 1.7
Enernst : 1.19075 V
Eta Activation : 0.3057086591103234 V
Eta Concentration : 0.00036244054765199196 V
Eta Ohmic : 0.0029939764517456784 V
Loss : 0.3090650761097211 V
PEM Efficiency : 0.5651826435194095
Power : 1.498864370613474 W
Power-Stack : 1.498864370613474 W
VStack : 0.8816849238902789 V
Vcell : 0.8816849238902789 V
###########
I : 1.8
Enernst : 1.19075 V
Eta Activation : 0.30949414368419487 V
Eta Concentration : 0.00038401843359268825 V
Eta Ohmic : 0.0031711328944759895 V
Loss : 0.3130492950122636 V
PEM Efficiency : 0.5626286570434207
Power : 1.5798612689779254 W
Power-Stack : 1.5798612689779254 W
VStack : 0.8777007049877363 V
Vcell : 0.8777007049877363 V
###########
I : 1.9
Enernst : 1.19075 V
Eta Activation : 0.3130749049111216 V
Eta Concentration : 0.00040562545915863245 V
Eta Ohmic : 0.003348406232555746 V
Loss : 0.31682893660283595 V
PEM Efficiency : 0.5602058098699769
Power : 1.6604500204546115 W
Power-Stack : 1.6604500204546115 W
VStack : 0.873921063397164 V
Vcell : 0.873921063397164 V
###########
I : 2.0
Enernst : 1.19075 V
Eta Activation : 0.3164719546471556 V
Eta Concentration : 0.0004272617031588504 V
Eta Ohmic : 0.0035257966966703337 V
Loss : 0.32042501304698484 V
PEM Efficiency : 0.5579006326621893
Power : 1.7406499739060304 W
Power-Stack : 1.7406499739060304 W
VStack : 0.8703249869530152 V
Vcell : 0.8703249869530152 V
###########
I : 2.1
Enernst : 1.19075 V
Eta Activation : 0.31970322720026056 V
Eta Concentration : 0.00044892724472251814 V
Eta Ohmic : 0.003703304521413451 V
Loss : 0.3238554589663965 V
PEM Efficiency : 0.5557016288676945
Power : 1.8204785361705675 W
Power-Stack : 1.8204785361705675 W
VStack : 0.8668945410336035 V
Vcell : 0.8668945410336035 V
###########
I : 2.2
Enernst : 1.19075 V
Eta Activation : 0.32278415246972747 V
Eta Concentration : 0.00047062216330069346 V
Eta Ohmic : 0.0038809299451994456 V
Loss : 0.3271357045782276 V
PEM Efficiency : 0.553598907321649
Power : 1.8999514499278993 W
Power-Stack : 1.8999514499278993 W
VStack : 0.8636142954217724 V
Vcell : 0.8636142954217724 V
###########
I : 2.3
Enernst : 1.19075 V
Eta Activation : 0.3257281015786805 V
Eta Concentration : 0.0004923465386680586 V
Eta Ohmic : 0.004058673210182234 V
Loss : 0.33027912132753073 V
PEM Efficiency : 0.5515838965849162
Power : 1.9790830209466792 W
Power-Stack : 1.9790830209466792 W
VStack : 0.8604708786724693 V
Vcell : 0.8604708786724693 V
###########
I : 2.4
Enernst : 1.19075 V
Eta Activation : 0.32854673759442776 V
Eta Concentration : 0.0005141004509246927 V
Eta Ohmic : 0.004236534562180054 V
Loss : 0.3332973726075325 V
PEM Efficiency : 0.5496491201233765
Power : 2.057886305741922 W
Power-Stack : 2.057886305741922 W
VStack : 0.8574526273924674 V
Vcell : 0.8574526273924674 V
###########
I : 2.5
Enernst : 1.19075 V
Eta Activation : 0.33125029460641553 V
Eta Concentration : 0.0005358839804978295 V
Eta Ohmic : 0.004414514250605397 V
Loss : 0.33620069283751874 V
PEM Efficiency : 0.5477880174118469
Power : 2.136373267906203 W
Power-Stack : 2.136373267906203 W
VStack : 0.8545493071624812 V
Vcell : 0.8545493071624812 V
###########
I : 2.6
Enernst : 1.19075 V
Eta Activation : 0.3338478020360954 V
Eta Concentration : 0.0005576972081436541 V
Eta Ohmic : 0.004592612528399569 V
Loss : 0.33899811177263856 V
PEM Efficiency : 0.5459948001457445
Power : 2.2145549093911394 W
Power-Stack : 2.2145549093911394 W
VStack : 0.8517518882273614 V
Vcell : 0.8517518882273614 V
###########
I : 2.7
Enernst : 1.19075 V
Eta Activation : 0.336347266590727 V
Eta Concentration : 0.0005795402149490941 V
Eta Ohmic : 0.004770829651971409 V
Loss : 0.3416976364576475 V
PEM Efficiency : 0.5442643356040721
Power : 2.292441381564352 W
Power-Stack : 2.292441381564352 W
VStack : 0.8490523635423525 V
Vcell : 0.8490523635423525 V
###########
I : 2.8
Enernst : 1.19075 V
Eta Activation : 0.33875582111049346 V
Eta Concentration : 0.0006014130823336223 V
Eta Ohmic : 0.00494916588113977 V
Loss : 0.34430640007396685 V
PEM Efficiency : 0.5425920512346366
Power : 2.3700420797928925 W
Power-Stack : 2.3700420797928925 W
VStack : 0.8464435999260331 V
Vcell : 0.8464435999260331 V
###########
I : 2.9
Enernst : 1.19075 V
Eta Activation : 0.3410798472843882 V
Eta Concentration : 0.0006233158920510905 V
Eta Ohmic : 0.005127621479079398 V
Loss : 0.34683078465551875 V
PEM Efficiency : 0.5409738559900521
Power : 2.4473657244989955 W
Power-Stack : 2.4473657244989955 W
VStack : 0.8439192153444812 V
Vcell : 0.8439192153444812 V
###########
I : 3.0
Enernst : 1.19075 V
Eta Activation : 0.3433250775536877 V
Eta Concentration : 0.0006452487261915484 V
Eta Ohmic : 0.005306196712269878 V
Loss : 0.3492765229921491 V
PEM Efficiency : 0.5394060750050326
Power : 2.524420431023553 W
Power-Stack : 2.524420431023553 W
VStack : 0.8414734770078509 V
Vcell : 0.8414734770078509 V
###########
I : 3.1
Enernst : 1.19075 V
Eta Activation : 0.3454966803001176 V
Eta Concentration : 0.0006672116671831024 V
Eta Ohmic : 0.005484891850447433 V
Loss : 0.3516487838177481 V
PEM Efficiency : 0.537885394988623
Power : 2.6012137701649807 W
Power-Stack : 2.6012137701649807 W
VStack : 0.8391012161822519 V
Vcell : 0.8391012161822519 V
###########
I : 3.2
Enernst : 1.19075 V
Eta Activation : 0.3475993315046607 V
Eta Concentration : 0.0006892047977937692 V
Eta Ohmic : 0.00566370716655928 V
Loss : 0.35395224346901377 V
PEM Efficiency : 0.5364088182890937
Power : 2.677752820899156 W
Power-Stack : 2.677752820899156 W
VStack : 0.8367977565309862 V
Vcell : 0.8367977565309862 V
###########
I : 3.3
Enernst : 1.19075 V
Eta Activation : 0.34963727537625955 V
Eta Concentration : 0.0007112282011333409 V
Eta Ohmic : 0.005842642936720367 V
Loss : 0.35619114651411327 V
PEM Efficiency : 0.5349736240294146
Power : 2.7540442165034262 W
Power-Stack : 2.7540442165034262 W
VStack : 0.8345588534858868 V
Vcell : 0.8345588534858868 V
###########
I : 3.4
Enernst : 1.19075 V
Eta Activation : 0.35161437592708844 V
Eta Concentration : 0.0007332819606552831 V
Eta Ohmic : 0.00602169944017227 V
Loss : 0.358369357327916 V
PEM Efficiency : 0.5335773350462076
Power : 2.8300941850850854 W
Power-Stack : 2.8300941850850854 W
VStack : 0.8323806426720839 V
Vcell : 0.8323806426720839 V
###########
I : 3.5
Enernst : 1.19075 V
Eta Activation : 0.3535341610697534 V
Eta Concentration : 0.0007553661601586168 V
Eta Ohmic : 0.006200876959244138 V
Loss : 0.3604904041891562 V
PEM Efficiency : 0.5322176896223357
Power : 2.9059085853379534 W
Power-Stack : 2.9059085853379534 W
VStack : 0.8302595958108439 V
Vcell : 0.8302595958108439 V
###########
I : 3.6
Enernst : 1.19075 V
Eta Activation : 0.3553998605009599 V
Eta Concentration : 0.000777480883789843 V
Eta Ohmic : 0.0063801757793154595 V
Loss : 0.36255751716406515 V
PEM Efficiency : 0.5308926172025222
Power : 2.9814929382093656 W
Power-Stack : 2.9814929382093656 W
VStack : 0.8281924828359348 V
Vcell : 0.8281924828359348 V
###########
I : 3.7
Enernst : 1.19075 V
Eta Activation : 0.3572144383935416 V
Eta Concentration : 0.0007996262160448594 V
Eta Ohmic : 0.0065595961887805875 V
Loss : 0.36457366079836706 V
PEM Efficiency : 0.5296002174369442
Power : 3.056852455046042 W
Power-Stack : 3.056852455046042 W
VStack : 0.8261763392016329 V
Vcell : 0.8261763392016329 V
###########
I : 3.8
Enernst : 1.19075 V
Eta Activation : 0.35898062172788664 V
Eta Concentration : 0.0008218022417708932 V
Eta Ohmic : 0.0067391384790148525 V
Loss : 0.3665415624486724 V
PEM Efficiency : 0.5283387420200818
Power : 3.1319920626950446 W
Power-Stack : 3.1319920626950446 W
VStack : 0.8242084375513276 V
Vcell : 0.8242084375513276 V
###########
I : 3.9
Enernst : 1.19075 V
Eta Activation : 0.36070092494262745 V
Eta Concentration : 0.0008440090461684635 V
Eta Ohmic : 0.0069188029443421825 V
Loss : 0.36846373693313805 V
PEM Efficiency : 0.527106578889014
Power : 3.2069164259607614 W
Power-Stack : 3.2069164259607614 W
VStack : 0.8222862630668619 V
Vcell : 0.8222862630668619 V
###########
Done!
>>> from opem.Static.Chamberline_Kim import *
>>> E0=0.982
>>> b=0.0689
>>> R=0.328
>>> m=0.000125
>>> n=9.45
>>> i=1
>>> A=50.0
>>> Vcell_Calc(E0,b,R,m,n,i,A)
1.244827379954939
>>> Vcell_Calc(None,b,R,m,n,i,A)
[Error] Vcell Calculation Error (E0:None, b:0.0689, R:0.328, m:0.000125, n:9.45, i:1, A:50.0)
>>> Static_Analysis(InputMethod={}, TestMode=True)
###########
Chamberline-Kim-Model Simulation
###########
Analyzing . . .
[Error] Chamberline-Kim Simulation Failed!(Check Your Inputs)
>>> Test_Vector={"A":50.0,"E0":0.982,"b":0.0689,"R":0.328,"m":0.000125,"n":9.45,"N":1,"i-start":1,"i-stop":4,"i-step":0.1,"Name":"test2"}
>>> Chamberline_Kim_Data=Static_Analysis(InputMethod=Test_Vector, TestMode=True)
###########
Chamberline-Kim-Model Simulation
###########
Analyzing . . .
I : 1
PEM Efficiency : 0.797966269201884
Power : 1.244827379954939 W
Power-Stack : 1.244827379954939 W
VStack : 1.244827379954939 V
Vcell : 1.244827379954939 V
###########
I : 1.1
PEM Efficiency : 0.7933343765568479
Power : 1.3613617901715511 W
Power-Stack : 1.3613617901715511 W
VStack : 1.2376016274286827 V
Vcell : 1.2376016274286827 V
###########
I : 1.2
PEM Efficiency : 0.7890689791314186
Power : 1.4771371289340156 W
Power-Stack : 1.4771371289340156 W
VStack : 1.230947607445013 V
Vcell : 1.230947607445013 V
###########
I : 1.3
PEM Efficiency : 0.7851113286904084
Power : 1.5922057745841485 W
Power-Stack : 1.5922057745841485 W
VStack : 1.2247736727570373 V
Vcell : 1.2247736727570373 V
###########
I : 1.4
PEM Efficiency : 0.7814157591393215
Power : 1.706612017960278 W
Power-Stack : 1.706612017960278 W
VStack : 1.2190085842573415 V
Vcell : 1.2190085842573415 V
###########
I : 1.5
PEM Efficiency : 0.7779460692405816
Power : 1.820393802022961 W
Power-Stack : 1.820393802022961 W
VStack : 1.2135958680153074 V
Vcell : 1.2135958680153074 V
###########
I : 1.6
PEM Efficiency : 0.7746730751436158
Power : 1.933583995558465 W
Power-Stack : 1.933583995558465 W
VStack : 1.2084899972240406 V
Vcell : 1.2084899972240406 V
###########
I : 1.7
PEM Efficiency : 0.771572906202878
Power : 2.0462113472500323 W
Power-Stack : 2.0462113472500323 W
VStack : 1.2036537336764896 V
Vcell : 1.2036537336764896 V
###########
I : 1.8
PEM Efficiency : 0.7686257886450131
Power : 2.158301214515197 W
Power-Stack : 2.158301214515197 W
VStack : 1.1990562302862204 V
Vcell : 1.1990562302862204 V
###########
I : 1.9
PEM Efficiency : 0.7658151585364871
Power : 2.2698761299021477 W
Power-Stack : 2.2698761299021477 W
VStack : 1.1946716473169199 V
Vcell : 1.1946716473169199 V
###########
I : 2.0
PEM Efficiency : 0.7631270025420254
Power : 2.380956247931119 W
Power-Stack : 2.380956247931119 W
VStack : 1.1904781239655595 V
Vcell : 1.1904781239655595 V
###########
I : 2.1
PEM Efficiency : 0.7605493596935309
Power : 2.491559702356007 W
Power-Stack : 2.491559702356007 W
VStack : 1.1864570011219082 V
Vcell : 1.1864570011219082 V
###########
I : 2.2
PEM Efficiency : 0.7580719391696471
Power : 2.601702895230229 W
Power-Stack : 2.601702895230229 W
VStack : 1.1825922251046495 V
Vcell : 1.1825922251046495 V
###########
I : 2.3
PEM Efficiency : 0.7556858231082223
Power : 2.7114007333123014 W
Power-Stack : 2.7114007333123014 W
VStack : 1.1788698840488268 V
Vcell : 1.1788698840488268 V
###########
I : 2.4
PEM Efficiency : 0.753383232714607
Power : 2.820666823283489 W
Power-Stack : 2.820666823283489 W
VStack : 1.1752778430347872 V
Vcell : 1.1752778430347872 V
###########
I : 2.5
PEM Efficiency : 0.7511573421474446
Power : 2.929513634375034 W
Power-Stack : 2.929513634375034 W
VStack : 1.1718054537500135 V
Vcell : 1.1718054537500135 V
###########
I : 2.6
PEM Efficiency : 0.7490021289286691
Power : 3.0379526349346824 W
Power-Stack : 3.0379526349346824 W
VStack : 1.168443321128724 V
Vcell : 1.168443321128724 V
###########
I : 2.7
PEM Efficiency : 0.7469122526002784
Power : 3.145994407952373 W
Power-Stack : 3.145994407952373 W
VStack : 1.1651831140564344 V
Vcell : 1.1651831140564344 V
###########
I : 2.8
PEM Efficiency : 0.7448829554595718
Power : 3.2536487494474096 W
Power-Stack : 3.2536487494474096 W
VStack : 1.162017410516932 V
Vcell : 1.162017410516932 V
###########
I : 2.9
PEM Efficiency : 0.7429099807210011
Power : 3.360924752781809 W
Power-Stack : 3.360924752781809 W
VStack : 1.1589395699247618 V
Vcell : 1.1589395699247618 V
###########
I : 3.0
PEM Efficiency : 0.7409895045575802
Power : 3.4678308813294754 W
Power-Stack : 3.4678308813294754 W
VStack : 1.1559436271098251 V
Vcell : 1.1559436271098251 V
###########
I : 3.1
PEM Efficiency : 0.7391180792895339
Power : 3.5743750314441862 W
Power-Stack : 3.5743750314441862 W
VStack : 1.153024203691673 V
Vcell : 1.153024203691673 V
###########
I : 3.2
PEM Efficiency : 0.7372925855955158
Power : 3.6805645872928157 W
Power-Stack : 3.6805645872928157 W
VStack : 1.1501764335290048 V
Vcell : 1.1501764335290048 V
###########
I : 3.3
PEM Efficiency : 0.7355101920796727
Power : 3.786406468826155 W
Power-Stack : 3.786406468826155 W
VStack : 1.1473958996442895 V
Vcell : 1.1473958996442895 V
###########
I : 3.4
PEM Efficiency : 0.7337683208763324
Power : 3.891907173928067 W
Power-Stack : 3.891907173928067 W
VStack : 1.1446785805670785 V
Vcell : 1.1446785805670785 V
###########
I : 3.5
PEM Efficiency : 0.7320646182417239
Power : 3.9970728155998123 W
Power-Stack : 3.9970728155998123 W
VStack : 1.1420208044570892 V
Vcell : 1.1420208044570892 V
###########
I : 3.6
PEM Efficiency : 0.7303969292894269
Power : 4.101909154889422 W
Power-Stack : 4.101909154889422 W
VStack : 1.1394192096915061 V
Vcell : 1.1394192096915061 V
###########
I : 3.7
PEM Efficiency : 0.7287632761880597
Power : 4.206421630157481 W
Power-Stack : 4.206421630157481 W
VStack : 1.136870710853373 V
Vcell : 1.136870710853373 V
###########
I : 3.8
PEM Efficiency : 0.7271618392669932
Power : 4.310615383174736 W
Power-Stack : 4.310615383174736 W
VStack : 1.1343724692565096 V
Vcell : 1.1343724692565096 V
###########
I : 3.9
PEM Efficiency : 0.7255909405767029
Power : 4.414495282468661 W
Power-Stack : 4.414495282468661 W
VStack : 1.1319218672996567 V
Vcell : 1.1319218672996567 V
###########
Done!
>>> from opem.Static.Larminie_Dicks import *
>>> E0=1.178
>>> A=0.0587
>>> B=0.0517
>>> RM=0.0018
>>> i_0=0.00654
>>> i_L=100
>>> i_n=0.23
>>> N=23
>>> Vcell_Calc(E0=E0, i=1,i_0=i_0,i_n=i_n,i_L=i_L,R_M=RM,A=A,B=B)
0.8677440917797067
>>> Vcell_Calc(E0=None, i=1,i_0=i_0,i_n=i_n,i_L=i_L,R_M=RM,A=A,B=B)
[Error] Vcell Calculation Error (E0:None, i:1, i_0:0.00654, i_n:0.23, i_L:100, R_M:0.0018, A:0.0587, B:0.0517)
>>> Static_Analysis(InputMethod={}, TestMode=True)
###########
Larminie-Dicks-Model Simulation
###########
Analyzing . . .
[Error] Larminiee Simulation Failed!(Check Your Inputs)
>>> Test_Vector={"A":0.0587,"E0":1.178,"B":0.0517,"RM":0.0018,"i_0":0.00654,"i_L":100.0,"i_n":0.23,"N":23,"i-start":0.1,"i-stop":4,"i-step":0.1,"Name":"test3"}
>>> Larminie_Dicks_Data=Static_Analysis(InputMethod=Test_Vector, TestMode=True)
###########
Larminie-Dicks-Model Simulation
###########
Analyzing . . .
I : 0.1
PEM Efficiency : 0.6070918465825977
Power : 0.09470632806688527 W
Power-Stack : 2.178245545538361 W
VStack : 21.78245545538361 V
Vcell : 0.9470632806688526 V
###########
I : 0.2
PEM Efficiency : 0.596983288796134
Power : 0.18625878610439384 W
Power-Stack : 4.2839520804010585 W
VStack : 21.41976040200529 V
Vcell : 0.9312939305219692 V
###########
I : 0.3
PEM Efficiency : 0.5889668542476844
Power : 0.27563648778791633 W
Power-Stack : 6.339639219122075 W
VStack : 21.132130730406917 V
Vcell : 0.9187882926263877 V
###########
I : 0.4
PEM Efficiency : 0.5823143704480743
Power : 0.3633641671595984 W
Power-Stack : 8.357375844670763 W
VStack : 20.893439611676907 V
Vcell : 0.908410417898996 V
###########
I : 0.5
PEM Efficiency : 0.576622053314997
Power : 0.4497652015856977 W
Power-Stack : 10.344599636471047 W
VStack : 20.689199272942094 V
Vcell : 0.8995304031713954 V
###########
I : 0.6
PEM Efficiency : 0.5716425142657562
Power : 0.5350573933527478 W
Power-Stack : 12.3063200471132 W
VStack : 20.510533411855334 V
Vcell : 0.8917623222545797 V
###########
I : 0.7
PEM Efficiency : 0.5672131517182866
Power : 0.6193967616763688 W
Power-Stack : 14.246125518556482 W
VStack : 20.35160788365212 V
Vcell : 0.884852516680527 V
###########
I : 0.8
PEM Efficiency : 0.5632213484876261
Power : 0.7029002429125574 W
Power-Stack : 16.16670558698882 W
VStack : 20.208381983736025 V
Vcell : 0.8786253036406967 V
###########
I : 0.9
PEM Efficiency : 0.5595858755325545
Power : 0.7856585692477064 W
Power-Stack : 18.070147092697248 W
VStack : 20.07794121410805 V
Vcell : 0.8729539658307849 V
###########
I : 1.0
PEM Efficiency : 0.5562462126792992
Power : 0.8677440917797067 W
Power-Stack : 19.958114110933252 W
VStack : 19.958114110933252 V
Vcell : 0.8677440917797067 V
###########
I : 1.1
PEM Efficiency : 0.5531560572234717
Power : 0.9492157941954775 W
Power-Stack : 21.831963266495983 W
VStack : 19.847239333178166 V
Vcell : 0.8629234492686159 V
###########
I : 1.2
PEM Efficiency : 0.5502791922121564
Power : 1.0301226478211567 W
Power-Stack : 23.692820899886605 W
VStack : 19.74401741657217 V
Vcell : 0.858435539850964 V
###########
I : 1.3
PEM Efficiency : 0.5475867544887774
Power : 1.1105059381032407 W
Power-Stack : 25.541636576374536 W
VStack : 19.647412751057335 V
Vcell : 0.8542353370024928 V
###########
I : 1.4
PEM Efficiency : 0.5450553693735705
Power : 1.190400926711878 W
Power-Stack : 27.379221314373194 W
VStack : 19.55658665312371 V
Vcell : 0.85028637622277 V
###########
I : 1.5
PEM Efficiency : 0.5426658416714328
Power : 1.2698380695111529 W
Power-Stack : 29.206275598756516 W
VStack : 19.47085039917101 V
Vcell : 0.8465587130074352 V
###########
I : 1.6
PEM Efficiency : 0.5404022150580957
Power : 1.348843928785007 W
Power-Stack : 31.02341036205516 W
VStack : 19.389631476284475 V
Vcell : 0.8430274554906293 V
###########
I : 1.7
PEM Efficiency : 0.5382510820424253
Power : 1.427441869576512 W
Power-Stack : 32.83116300025978 W
VStack : 19.312448823682224 V
Vcell : 0.8396716879861836 V
###########
I : 1.8
PEM Efficiency : 0.536201068437617
Power : 1.5056526001728283 W
Power-Stack : 34.63000980397505 W
VStack : 19.238894335541694 V
Vcell : 0.8364736667626824 V
###########
I : 1.9
PEM Efficiency : 0.5342424419218519
Power : 1.583494597856369 W
Power-Stack : 36.420375750696486 W
VStack : 19.168618816156048 V
Vcell : 0.833418209398089 V
###########
I : 2.0
PEM Efficiency : 0.532366810486187
Power : 1.6609844487169034 W
Power-Stack : 38.20264232048878 W
VStack : 19.10132116024439 V
Vcell : 0.8304922243584517 V
###########
I : 2.1
PEM Efficiency : 0.5305668870842597
Power : 1.738137122088035 W
Power-Stack : 39.97715380802481 W
VStack : 19.03673990858324 V
Vcell : 0.8276843438514452 V
###########
I : 2.2
PEM Efficiency : 0.5288363037744284
Power : 1.8149661945538385 W
Power-Stack : 41.74422247473829 W
VStack : 18.97464657942649 V
Vcell : 0.8249846338881083 V
###########
I : 2.3
PEM Efficiency : 0.527169463367337
Power : 1.891484034562005 W
Power-Stack : 43.504132794926115 W
VStack : 18.914840345620053 V
Vcell : 0.8223843628530457 V
###########
I : 2.4
PEM Efficiency : 0.5255614198480028
Power : 1.9677019559109223 W
Power-Stack : 45.257144985951214 W
VStack : 18.857143744146338 V
Vcell : 0.8198758149628843 V
###########
I : 2.5
PEM Efficiency : 0.5240077811244296
Power : 2.0436303463852754 W
Power-Stack : 47.00349796686133 W
VStack : 18.801399186744536 V
Vcell : 0.8174521385541103 V
###########
I : 2.6
PEM Efficiency : 0.5225046292799733
Power : 2.1192787763595717 W
Power-Stack : 48.74341185627015 W
VStack : 18.74746609856544 V
Vcell : 0.8151072216767583 V
###########
I : 2.7
PEM Efficiency : 0.52104845467996
Power : 2.194656091111992 W
Power-Stack : 50.47709009557581 W
VStack : 18.695218553916966 V
Vcell : 0.8128355893007376 V
###########
I : 2.8
PEM Efficiency : 0.5196361011410657
Power : 2.269770489784175 W
Power-Stack : 52.20472126503602 W
VStack : 18.644543308941437 V
Vcell : 0.8106323177800625 V
###########
I : 2.9
PEM Efficiency : 0.5182647200068938
Power : 2.3446295933111876 W
Power-Stack : 53.926480646157316 W
VStack : 18.59533815384735 V
Vcell : 0.8084929632107544 V
###########
I : 3.0
PEM Efficiency : 0.5169317314482642
Power : 2.4192405031778765 W
Power-Stack : 55.64253157309116 W
VStack : 18.54751052436372 V
Vcell : 0.8064135010592922 V
###########
I : 3.1
PEM Efficiency : 0.515634791665824
Power : 2.4936098524959247 W
Power-Stack : 57.35302660740627 W
VStack : 18.500976324969766 V
Vcell : 0.8043902749986854 V
###########
I : 3.2
PEM Efficiency : 0.514371764946645
Power : 2.5677438506136525 W
Power-Stack : 59.05810856411401 W
VStack : 18.455658926285626 V
Vcell : 0.8024199533167663 V
###########
I : 3.3
PEM Efficiency : 0.5131406997374682
Power : 2.6416483222484866 W
Power-Stack : 60.75791141171519 W
VStack : 18.411488306580363 V
Vcell : 0.8004994915904505 V
###########
I : 3.4
PEM Efficiency : 0.5119398080610783
Power : 2.7153287419559593 W
Power-Stack : 62.452561064987066 W
VStack : 18.36840031323149 V
Vcell : 0.7986261005752822 V
###########
I : 3.5
PEM Efficiency : 0.5107674477304784
Power : 2.788790264608412 W
Power-Stack : 64.14217608599348 W
VStack : 18.326336024569564 V
Vcell : 0.7967972184595463 V
###########
I : 3.6
PEM Efficiency : 0.5096221069165698
Power : 2.862037752443456 W
Power-Stack : 65.82686830619949 W
VStack : 18.285241196166524 V
Vcell : 0.7950104867898489 V
###########
I : 3.7
PEM Efficiency : 0.5085023907052405
Power : 2.935075799150648 W
Power-Stack : 67.50674338046491 W
VStack : 18.24506577850403 V
Vcell : 0.7932637295001752 V
###########
I : 3.8
PEM Efficiency : 0.5074070093438323
Power : 3.007908751390238 W
Power-Stack : 69.18190128197547 W
VStack : 18.205763495256704 V
Vcell : 0.7915549345763785 V
###########
I : 3.9
PEM Efficiency : 0.5063347679284521
Power : 3.080540728076703 W
Power-Stack : 70.85243674576417 W
VStack : 18.167291473272865 V
Vcell : 0.7898822379683854 V
###########
Done!
>>> Input_dict=Get_Input({"T": "Cell Operation Temperature [K]", "PH2": "Partial Pressure [atm]", "PO2": "Partial Pressure [atm]"},input_item=input_test)
>>> Input_keys=list(Input_dict.keys())
>>> Input_keys.sort()
>>> print(Input_keys)
['Name', 'PH2', 'PO2', 'T']
>>> from opem.Dynamic.Padulles1 import *
>>> Test_Vector={"T":343,"E0":0.6,"N0":88,"KO2":0.0000211,"KH2":0.0000422,"tH2":3.37,"tO2":6.74,"B":0.04777,"C":0.0136,"Rint":0.00303,"rho":1.168,"qH2":0.0004,"i-start":0,"i-stop":4,"i-step":0.1,"Name":"test3"}
>>> Padulles_I_Data=Dynamic_Analysis(InputMethod=Test_Vector, TestMode=True)
###########
Padulles-I-Model Simulation
###########
Analyzing . . .
[Error] Vcell Calculation Error (Enernst:54.28850557413407, B:0.04777, C:0.0136, I:0, Rint:0.00303)
[Error] PEM Efficiency Calculation Failed (Vcell:None, N:88)
[Error] Power Calculation Error (Vcell:None, i:0)
I : 0
E : 54.28850557413407 V
FC Efficiency : None
FC Power : None W
FC Voltage : None V
PH2 : 2.169032719858579 atm
PO2 : 2.0969773162414582 atm
###########
I : 0.1
E : 54.288313997298886 V
FC Efficiency : 0.3977513543332525
FC Power : 5.4603305922868905 W
FC Voltage : 54.6033059228689 V
PH2 : 2.168785433142166 atm
PO2 : 2.096837698289168 atm
###########
I : 0.2
E : 54.28812240067271 V
FC Efficiency : 0.39750655365258875
FC Power : 10.913939937085477 W
FC Voltage : 54.56969968542738 V
PH2 : 2.1685381464257527 atm
PO2 : 2.096698080336878 atm
###########
I : 0.3
E : 54.287930784251316 V
FC Efficiency : 0.39736185898012566
FC Power : 16.364950800237498 W
FC Voltage : 54.54983600079166 V
PH2 : 2.168290859709339 atm
PO2 : 2.096558462384588 atm
###########
I : 0.4
E : 54.28773914803044 V
FC Efficiency : 0.3972581497084044
FC Power : 21.814239516787904 W
FC Voltage : 54.535598791969754 V
PH2 : 2.1680435729929264 atm
PO2 : 2.0964188444322978 atm
###########
I : 0.5
E : 54.28754749200584 V
FC Efficiency : 0.3971768980805572
FC Power : 27.262222284249443 W
FC Voltage : 54.524444568498886 V
PH2 : 2.1677962862765128 atm
PO2 : 2.0962792264800076 atm
###########
I : 0.6
E : 54.28735581617328 V
FC Efficiency : 0.3971098513395853
FC Power : 32.709144235138965 W
FC Voltage : 54.515240391898274 V
PH2 : 2.1675489995600996 atm
PO2 : 2.0961396085277175 atm
###########
I : 0.7
E : 54.287164120528516 V
FC Efficiency : 0.3970526072135646
FC Power : 38.155167342794705 W
FC Voltage : 54.507381918278156 V
PH2 : 2.1673017128436864 atm
PO2 : 2.0959999905754274 atm
###########
I : 0.8
E : 54.28697240506729 V
FC Efficiency : 0.39700253793845613
FC Power : 43.60040672655301 W
FC Voltage : 54.50050840819126 V
PH2 : 2.1670544261272733 atm
PO2 : 2.0958603726231373 atm
###########
I : 0.9
E : 54.286780669785365 V
FC Efficiency : 0.39695794855256433
FC Power : 49.044948459566434 W
FC Voltage : 54.49438717729603 V
PH2 : 2.16680713941086 atm
PO2 : 2.0957207546708467 atm
###########
I : 1.0
E : 54.28658891467849 V
FC Efficiency : 0.39691768174793257
FC Power : 54.48885935035618 W
FC Voltage : 54.48885935035618 V
PH2 : 2.166559852694447 atm
PO2 : 2.0955811367185566 atm
###########
I : 1.1
E : 54.2863971397424 V
FC Efficiency : 0.39688091206389015
FC Power : 59.93219276894392 W
FC Voltage : 54.483811608130836 V
PH2 : 2.1663125659780333 atm
PO2 : 2.095441518766267 atm
###########
I : 1.2
E : 54.286205344972856 V
FC Efficiency : 0.3968470300107991
FC Power : 65.37499233585899 W
FC Voltage : 54.4791602798825 V
PH2 : 2.16606527926162 atm
PO2 : 2.0953019008139764 atm
###########
I : 1.3
E : 54.286013530365594 V
FC Efficiency : 0.3968155727355017
FC Power : 70.81729437266857 W
FC Voltage : 54.47484182512967 V
PH2 : 2.165817992545207 atm
PO2 : 2.0951622828616863 atm
###########
I : 1.4
E : 54.28582169591637 V
FC Efficiency : 0.3967861804549145
FC Power : 76.25912959399092 W
FC Voltage : 54.470806852850664 V
PH2 : 2.165570705828794 atm
PO2 : 2.095022664909396 atm
###########
I : 1.5
E : 54.28562984162091 V
FC Efficiency : 0.3967585679566162
FC Power : 81.7005243136264 W
FC Voltage : 54.46701620908427 V
PH2 : 2.1653234191123807 atm
PO2 : 2.094883046957106 atm
###########
I : 1.6
E : 54.28543796747497 V
FC Efficiency : 0.39673250531602267
FC Power : 87.14150132765376 W
FC Voltage : 54.46343832978359 V
PH2 : 2.1650761323959675 atm
PO2 : 2.094743429004816 atm
###########
I : 1.7
E : 54.28524607347429 V
FC Efficiency : 0.3967078044696878
FC Power : 92.58208057591786 W
FC Voltage : 54.46004739759874 V
PH2 : 2.164828845679554 atm
PO2 : 2.094603811052526 atm
###########
I : 1.8
E : 54.285054159614596 V
FC Efficiency : 0.3966843096322109
FC Power : 98.02227964735785 W
FC Voltage : 54.456822026309915 V
PH2 : 2.164581558963141 atm
PO2 : 2.0944641931002357 atm
###########
I : 1.9
E : 54.284862225891644 V
FC Efficiency : 0.3966618903075967
FC Power : 103.46211417271105 W
FC Voltage : 54.45374430142687 V
PH2 : 2.1643342722467276 atm
PO2 : 2.094324575147945 atm
###########
I : 2.0
E : 54.28467027230115 V
FC Efficiency : 0.39664043609530514
FC Power : 108.90159813432699 W
FC Voltage : 54.450799067163494 V
PH2 : 2.1640869855303144 atm
PO2 : 2.0941849571956554 atm
###########
I : 2.1
E : 54.28447829883886 V
FC Efficiency : 0.3966198527648516
FC Power : 114.34074411387355 W
FC Voltage : 54.44797338755883 V
PH2 : 2.1638396988139013 atm
PO2 : 2.094045339243365 atm
###########
I : 2.2
E : 54.2842863055005 V
FC Efficiency : 0.3966000592444172
FC Power : 119.77956349276191 W
FC Voltage : 54.44525613307359 V
PH2 : 2.1635924120974876 atm
PO2 : 2.0939057212910748 atm
###########
I : 2.3
E : 54.284094292281814 V
FC Efficiency : 0.39658098527940633
FC Power : 125.21806661606087 W
FC Voltage : 54.4426376591569 V
PH2 : 2.163345125381075 atm
PO2 : 2.0937661033387847 atm
###########
I : 2.4
E : 54.28390225917852 V
FC Efficiency : 0.3965625695896912
FC Power : 130.65626292785475 W
FC Voltage : 54.44010955327281 V
PH2 : 2.1630978386646613 atm
PO2 : 2.0936264853864945 atm
###########
I : 2.5
E : 54.28371020618635 V
FC Efficiency : 0.3965447584032809
FC Power : 136.09416108400603 W
FC Voltage : 54.43766443360241 V
PH2 : 2.162850551948248 atm
PO2 : 2.0934868674342044 atm
###########
I : 2.6
E : 54.28351813330103 V
FC Efficiency : 0.3965275042777518
FC Power : 141.5317690468494 W
FC Voltage : 54.435295787249764 V
PH2 : 2.162603265231835 atm
PO2 : 2.0933472494819143 atm
###########
I : 2.7
E : 54.2833260405183 V
FC Efficiency : 0.39651076514422556
FC Power : 146.9690941652981 W
FC Voltage : 54.432997838999285 V
PH2 : 2.162355978515422 atm
PO2 : 2.093207631529624 atm
###########
I : 2.8
E : 54.28313392783386 V
FC Efficiency : 0.3964945035252972
FC Power : 152.40614324306785 W
FC Voltage : 54.4307654439528 V
PH2 : 2.1621086917990087 atm
PO2 : 2.093068013577334 atm
###########
I : 2.9
E : 54.28294179524345 V
FC Efficiency : 0.39647868589026086
FC Power : 157.84292259714354 W
FC Voltage : 54.428593999015014 V
PH2 : 2.1618614050825955 atm
PO2 : 2.092928395625044 atm
###########
I : 3.0
E : 54.282749642742786 V
FC Efficiency : 0.39646328211968823
FC Power : 163.2794381081724 W
FC Voltage : 54.4264793693908 V
PH2 : 2.161614118366182 atm
PO2 : 2.0927887776727534 atm
###########
I : 3.1
E : 54.282557470327596 V
FC Efficiency : 0.3964482650578333
FC Power : 168.71569526413202 W
FC Voltage : 54.42441782713936 V
PH2 : 2.1613668316497687 atm
PO2 : 2.0926491597204633 atm
###########
I : 3.2
E : 54.282365277993584 V
FC Efficiency : 0.39643361013612227
FC Power : 174.15169919835796 W
FC Voltage : 54.42240599948686 V
PH2 : 2.1611195449333556 atm
PO2 : 2.0925095417681736 atm
###########
I : 3.3
E : 54.282173065736494 V
FC Efficiency : 0.39641929505459833
FC Power : 179.58745472281433 W
FC Voltage : 54.420440825095255 V
PH2 : 2.1608722582169424 atm
PO2 : 2.092369923815883 atm
###########
I : 3.4
E : 54.28198083355201 V
FC Efficiency : 0.3964052995109346
FC Power : 185.02296635732776 W
FC Voltage : 54.41851951686111 V
PH2 : 2.1606249715005292 atm
PO2 : 2.092230305863593 atm
###########
I : 3.5
E : 54.28178858143586 V
FC Efficiency : 0.3963916049687393
FC Power : 190.45823835537988 W
FC Voltage : 54.41663953010853 V
PH2 : 2.160377684784116 atm
PO2 : 2.092090687911303 atm
###########
I : 3.6
E : 54.281596309383765 V
FC Efficiency : 0.39637819445850625
FC Power : 195.89327472694944 W
FC Voltage : 54.414798535263735 V
PH2 : 2.1601303980677025 atm
PO2 : 2.0919510699590127 atm
###########
I : 3.7
E : 54.281404017391424 V
FC Efficiency : 0.39636505240584513
FC Power : 201.32807925881536 W
FC Voltage : 54.41299439427442 V
PH2 : 2.1598831113512893 atm
PO2 : 2.0918114520067226 atm
###########
I : 3.8
E : 54.28121170545457 V
FC Efficiency : 0.3963521644826228
FC Power : 206.76265553266293 W
FC Voltage : 54.41122514017446 V
PH2 : 2.159635824634876 atm
PO2 : 2.0916718340544325 atm
###########
I : 3.9
E : 54.28101937356888 V
FC Efficiency : 0.39633951747744234
FC Power : 212.1970069412828 W
FC Voltage : 54.40948895930328 V
PH2 : 2.159388537918463 atm
PO2 : 2.0915322161021423 atm
###########
Done!
>>> Dynamic_Analysis(InputMethod={}, TestMode=True)
###########
Padulles-I-Model Simulation
###########
Analyzing . . .
[Error] Dynamic Simulation Failed!(Check Your Inputs)
>>> Enernst_Calc(E0=None,N0=0,T=1, PH2=2.1, PO2=2.1)
[Error] Enernst Calculation Failed (E0:None, N0:0, T:1, PH2:2.1, PO2:2.1)
>>> PH2_Calc(KH2=None,tH2=1,Kr=0.3,I=3,qH2=0.3)
[Error] PH2 Calculation Failed (KH2:None, tH2:1, Kr:0.3, I:3, qH2:0.3)
>>> PO2_Calc(KO2=None,tO2=1.2,Kr=0.3,I=5,qO2=0.3)
[Error] PO2 Calculation Failed (KO2:None, tO2:1.2, Kr:0.3, I:5, qO2:0.3)
>>> Kr_Calc(N0=None)
[Error] Kr Calculation Failed (N0:None)
>>> qO2_Calc(qH2=2,rho=0)
[Error] qO2 Calculation Error (qH2:2, rho:0)
>>> from opem.Dynamic.Padulles2 import *
>>> Test_Vector={"T":343,"E0":0.6,"N0":5,"KO2":0.0000211,"KH2":0.0000422,"KH2O":0.000007716,"tH2":3.37,"tO2":6.74,"tH2O":18.418,"B":0.04777,"C":0.0136,"Rint":0.00303,"rho":1.168,"qH2":0.0004,"qH2O":0.0004,"i-start":0.1,"i-stop":4,"i-step":0.1,"Name":"test3"}
>>> Padulles_II_Data=Dynamic_Analysis(InputMethod=Test_Vector, TestMode=True)
###########
Padulles-II-Model Simulation
###########
Analyzing . . .
I : 0.1
E : 3.0120122442199793 V
FC Efficiency : 0.4265389961269225
FC Power : 0.33270041697899955 W
FC Voltage : 3.3270041697899955 V
PH2 : 2.169018669476965 atm
PH2O : 2.669687710942903 atm
PO2 : 2.09696938340326 atm
###########
I : 0.2
E : 3.012012104448671 V
FC Efficiency : 0.42225504989786394
FC Power : 0.6587178778406679 W
FC Voltage : 3.293589389203339 V
PH2 : 2.1690046190953503 atm
PH2O : 2.6696704173475743 atm
PO2 : 2.0969614505650616 atm
###########
I : 0.3
E : 3.0120119646768333 V
FC Efficiency : 0.4197329719509197
FC Power : 0.9821751543651522 W
FC Voltage : 3.273917181217174 V
PH2 : 2.1689905687137356 atm
PH2O : 2.669653123752246 atm
PO2 : 2.0969535177268637 atm
###########
I : 0.4
E : 3.0120118249044676 V
FC Efficiency : 0.41793223959535725
FC Power : 1.3039485875375147 W
FC Voltage : 3.259871468843787 V
PH2 : 2.1689765183321215 atm
PH2O : 2.6696358301569174 atm
PO2 : 2.0969455848886653 atm
###########
I : 0.5
E : 3.0120116851315726 V
FC Efficiency : 0.41652676431084773
FC Power : 1.6244543808123062 W
FC Voltage : 3.2489087616246124 V
PH2 : 2.1689624679505073 atm
PH2O : 2.669618536561589 atm
PO2 : 2.096937652050467 atm
###########
I : 0.6
E : 3.012011545358149 V
FC Efficiency : 0.4153712975747617
FC Power : 1.943937672649885 W
FC Voltage : 3.2398961210831416 V
PH2 : 2.1689484175688927 atm
PH2O : 2.6696012429662606 atm
PO2 : 2.0969297192122687 atm
###########
I : 0.7
E : 3.0120114055841967 V
FC Efficiency : 0.4143883594017745
FC Power : 2.2625604423336885 W
FC Voltage : 3.232229203333841 V
PH2 : 2.1689343671872785 atm
PH2O : 2.669583949370932 atm
PO2 : 2.0969217863740703 atm
###########
I : 0.8
E : 3.0120112658097153 V
FC Efficiency : 0.4135317011453444
FC Power : 2.580437815146949 W
FC Voltage : 3.225547268933686 V
PH2 : 2.168920316805664 atm
PH2O : 2.6695666557756033 atm
PO2 : 2.096913853535872 atm
###########
I : 0.9
E : 3.0120111260347056 V
FC Efficiency : 0.41277149148017567
FC Power : 2.897655870190834 W
FC Voltage : 3.219617633545371 V
PH2 : 2.1689062664240497 atm
PH2O : 2.6695493621802746 atm
PO2 : 2.0969059206976737 atm
###########
I : 1.0
E : 3.0120109862591664 V
FC Efficiency : 0.4120873617867766
FC Power : 3.2142814219368576 W
FC Voltage : 3.2142814219368576 V
PH2 : 2.168892216042435 atm
PH2O : 2.669532068584946 atm
PO2 : 2.0968979878594753 atm
###########
I : 1.1
E : 3.0120108464830992 V
FC Efficiency : 0.4114647839578894
FC Power : 3.5303678463586916 W
FC Voltage : 3.2094253148715377 V
PH2 : 2.168878165660821 atm
PH2O : 2.6695147749896178 atm
PO2 : 2.096890055021277 atm
###########
I : 1.2
E : 3.0120107067065027 V
FC Efficiency : 0.41089303097642904
FC Power : 3.845958769939376 W
FC Voltage : 3.2049656416161465 V
PH2 : 2.1688641152792063 atm
PH2O : 2.669497481394289 atm
PO2 : 2.0968821221830787 atm
###########
I : 1.3
E : 3.0120105669293777 V
FC Efficiency : 0.4103639566273662
FC Power : 4.161090520201494 W
FC Voltage : 3.2008388616934567 V
PH2 : 2.168850064897592 atm
PH2O : 2.669480187798961 atm
PO2 : 2.0968741893448803 atm
###########
I : 1.4
E : 3.012010427151724 V
FC Efficiency : 0.40987122872897686
FC Power : 4.475793817720427 W
FC Voltage : 3.1969955840860194 V
PH2 : 2.168836014515978 atm
PH2O : 2.6694628942036323 atm
PO2 : 2.096866256506682 atm
###########
I : 1.5
E : 3.012010287373541 V
FC Efficiency : 0.409409827543193
FC Power : 4.790094982255358 W
FC Voltage : 3.1933966548369055 V
PH2 : 2.1688219641343633 atm
PH2O : 2.6694456006083036 atm
PO2 : 2.0968583236684837 atm
###########
I : 1.6
E : 3.0120101475948298 V
FC Efficiency : 0.40897570639787845
FC Power : 5.104016815845523 W
FC Voltage : 3.190010509903452 V
PH2 : 2.1688079137527487 atm
PH2O : 2.669428307012975 atm
PO2 : 2.096850390830286 atm
###########
I : 1.7
E : 3.012010007815589 V
FC Efficiency : 0.4085655553769282
FC Power : 5.417579264298068 W
FC Voltage : 3.18681133194004 V
PH2 : 2.1687938633711346 atm
PH2O : 2.6694110134176463 atm
PO2 : 2.0968424579920875 atm
###########
I : 1.8
E : 3.01200986803582 V
FC Efficiency : 0.40817663265783805
FC Power : 5.730799922516047 W
FC Voltage : 3.183777734731137 V
PH2 : 2.16877981298952 atm
PH2O : 2.6693937198223177 atm
PO2 : 2.096834525153889 atm
###########
I : 1.9
E : 3.012009728255522 V
FC Efficiency : 0.4078066415116356
FC Power : 6.04369442720244 W
FC Voltage : 3.180891803790758 V
PH2 : 2.1687657626079058 atm
PH2O : 2.669376426226989 atm
PO2 : 2.096826592315691 atm
###########
I : 2.0
E : 3.012009588474695 V
FC Efficiency : 0.40745363888936376
FC Power : 6.356276766674075 W
FC Voltage : 3.1781383833370374 V
PH2 : 2.168751712226291 atm
PH2O : 2.669359132631661 atm
PO2 : 2.0968186594774925 atm
###########
I : 2.1
E : 3.0120094486933398 V
FC Efficiency : 0.40711596633503955
FC Power : 6.668559528567949 W
FC Voltage : 3.1755045374133086 V
PH2 : 2.168737661844677 atm
PH2O : 2.669341839036332 atm
PO2 : 2.096810726639294 atm
###########
I : 2.2
E : 3.0120093089114555 V
FC Efficiency : 0.4067921969851981
FC Power : 6.980554100266 W
FC Voltage : 3.172979136484545 V
PH2 : 2.168723611463063 atm
PH2O : 2.669324545441004 atm
PO2 : 2.096802793801096 atm
###########
I : 2.3
E : 3.012009169129042 V
FC Efficiency : 0.4064810943595029
FC Power : 7.292270832809483 W
FC Voltage : 3.170552536004123 V
PH2 : 2.168709561081448 atm
PH2O : 2.6693072518456753 atm
PO2 : 2.0967948609628975 atm
###########
I : 2.4
E : 3.0120090293460997 V
FC Efficiency : 0.40618157992825576
FC Power : 7.603719176256948 W
FC Voltage : 3.168216323440395 V
PH2 : 2.168695510699834 atm
PH2O : 2.6692899582503467 atm
PO2 : 2.096786928124699 atm
###########
I : 2.5
E : 3.0120088895626287 V
FC Efficiency : 0.40589270730496035
FC Power : 7.914907792446728 W
FC Voltage : 3.1659631169786913 V
PH2 : 2.1686814603182194 atm
PH2O : 2.669272664655018 atm
PO2 : 2.096778995286501 atm
###########
I : 2.6
E : 3.0120087497786283 V
FC Efficiency : 0.40561364150350754
FC Power : 8.225844649691133 W
FC Voltage : 3.163786403727359 V
PH2 : 2.168667409936605 atm
PH2O : 2.6692553710596894 atm
PO2 : 2.0967710624483025 atm
###########
I : 2.7
E : 3.0120086099941004 V
FC Efficiency : 0.405343642112191
FC Power : 8.536537102882745 W
FC Voltage : 3.1616804084750902 V
PH2 : 2.1686533595549906 atm
PH2O : 2.6692380774643607 atm
PO2 : 2.096763129610104 atm
###########
I : 2.8
E : 3.0120084702090426 V
FC Efficiency : 0.4050820495292294
FC Power : 8.84699196171837 W
FC Voltage : 3.1596399863279894 V
PH2 : 2.168639309173376 atm
PH2O : 2.6692207838690325 atm
PO2 : 2.096755196771906 atm
###########
I : 2.9
E : 3.0120083304234564 V
FC Efficiency : 0.404828273614746
FC Power : 9.157215549165555 W
FC Voltage : 3.1576605341950192 V
PH2 : 2.168625258791762 atm
PH2O : 2.669203490273704 atm
PO2 : 2.0967472639337075 atm
###########
I : 3.0
E : 3.012008190637341 V
FC Efficiency : 0.40458178426735336
FC Power : 9.467213751856068 W
FC Voltage : 3.1557379172853564 V
PH2 : 2.1686112084101477 atm
PH2O : 2.6691861966783756 atm
PO2 : 2.0967393310955096 atm
###########
I : 3.1
E : 3.0120080508506963 V
FC Efficiency : 0.4043421035464688
FC Power : 9.776992063753617 W
FC Voltage : 3.1538684076624572 V
PH2 : 2.168597158028533 atm
PH2O : 2.669168903083047 atm
PO2 : 2.0967313982573113 atm
###########
I : 3.2
E : 3.0120079110635234 V
FC Efficiency : 0.40410879904574315
FC Power : 10.08655562418175 W
FC Voltage : 3.152048632556797 V
PH2 : 2.168583107646919 atm
PH2O : 2.6691516094877183 atm
PO2 : 2.096723465419113 atm
###########
I : 3.3
E : 3.0120077712758215 V
FC Efficiency : 0.40388147828648513
FC Power : 10.395909251094128 W
FC Voltage : 3.1502755306345844 V
PH2 : 2.1685690572653042 atm
PH2O : 2.6691343158923897 atm
PO2 : 2.0967155325809146 atm
###########
I : 3.4
E : 3.0120076314875908 V
FC Efficiency : 0.403659783948294
FC Power : 10.705057470308757 W
FC Voltage : 3.1485463147966937 V
PH2 : 2.16855500688369 atm
PH2O : 2.669117022297061 atm
PO2 : 2.0967075997427163 atm
###########
I : 3.5
E : 3.012007491698831 V
FC Efficiency : 0.4034433897912177
FC Power : 11.014004541300244 W
FC Voltage : 3.1468584403714983 V
PH2 : 2.1685409565020755 atm
PH2O : 2.6690997287017324 atm
PO2 : 2.096699666904518 atm
###########
I : 3.6
E : 3.0120073519095425 V
FC Efficiency : 0.4032319971525013
FC Power : 11.322754480042237 W
FC Voltage : 3.1452095777895104 V
PH2 : 2.168526906120461 atm
PH2O : 2.669082435106404 atm
PO2 : 2.0966917340663196 atm
###########
I : 3.7
E : 3.012007212119725 V
FC Efficiency : 0.40302533192342654
FC Power : 11.631311079310091 W
FC Voltage : 3.1435975890027272 V
PH2 : 2.1685128557388467 atm
PH2O : 2.6690651415110755 atm
PO2 : 2.0966838012281213 atm
###########
I : 3.8
E : 3.0120070723293786 V
FC Efficiency : 0.402823141929393
FC Power : 11.939677926787208 W
FC Voltage : 3.1420205070492657 V
PH2 : 2.168498805357232 atm
PH2O : 2.669047847915747 atm
PO2 : 2.096675868389923 atm
###########
I : 3.9
E : 3.0120069325385037 V
FC Efficiency : 0.4026251946503726
FC Power : 12.247858421264336 W
FC Voltage : 3.140476518272907 V
PH2 : 2.168484754975618 atm
PH2O : 2.6690305543204187 atm
PO2 : 2.0966679355517246 atm
###########
Done!
>>> Enernst_Calc(E0=None,N0=0,T=1, PH2=2.1, PO2=2.1,PH2O=2.1)
[Error] Enernst Calculation Failed (E0:None, N0:0, T:1, PH2:2.1, PO2:2.1, PH2O:2.1)
>>> PH2O_Calc(KH2O=None,tH2O=1,Kr=0.3,I=3,qH2O=0.3)
[Error] PH2O Calculation Failed (KH2O:None, tH2O:1, Kr:0.3, I:3, qH2O:0.3)
>>> Dynamic_Analysis(InputMethod={}, TestMode=True)
###########
Padulles-II-Model Simulation
###########
Analyzing . . .
[Error] Dynamic Simulation Failed!(Check Your Inputs)
>>> from opem.Dynamic.Padulles_Hauer import *
>>> Test_Vector={"T":343,"E0":0.6,"N0":5,"KO2":0.0000211,"KH2":0.0000422,"KH2O":0.000007716,"tH2":3.37,"tO2":6.74,"t1":2,"t2":2,"tH2O":18.418,"B":0.04777,"C":0.0136,"Rint":0.00303,"rho":1.168,"qMethanol":0.0002,"CV":2,"i-start":0.1,"i-stop":4,"i-step":0.1,"Name":"test3"}
>>> Padulles_Hauer_Data=Dynamic_Analysis(InputMethod=Test_Vector, TestMode=True)
###########
Padulles-Hauer-Model Simulation
###########
Analyzing . . .
I : 0.1
E : 2.9234154992732004 V
FC Efficiency : 0.41518043908246366
FC Power : 0.3238407424843217 W
FC Voltage : 3.2384074248432166 V
PH2 : 0.19717074233280188 atm
PH2O : 0.2426831613626925 atm
PO2 : 0.1906263686382979 atm
###########
I : 0.2
E : 2.9234139617015558 V
FC Efficiency : 0.4108963136482338
FC Power : 0.6409982492912448 W
FC Voltage : 3.204991246456224 V
PH2 : 0.1971566919511875 atm
PH2O : 0.24266586776736396 atm
PO2 : 0.1906184358000996 atm
###########
I : 0.3
E : 2.9234124240659227 V
FC Efficiency : 0.4083740564879825
FC Power : 0.955595292181879 W
FC Voltage : 3.1853176406062635 V
PH2 : 0.19714264156957312 atm
PH2O : 0.24264857417203542 atm
PO2 : 0.1906105029619013 atm
###########
I : 0.4
E : 2.9234108863662946 V
FC Efficiency : 0.4065731449109761
FC Power : 1.2685082121222457 W
FC Voltage : 3.171270530305614 V
PH2 : 0.19712859118795872 atm
PH2O : 0.24263128057670688 atm
PO2 : 0.19060257012370302 atm
###########
I : 0.5
E : 2.9234093486026658 V
FC Efficiency : 0.4051674903968853
FC Power : 1.5801532125478528 W
FC Voltage : 3.1603064250957056 V
PH2 : 0.19711454080634436 atm
PH2O : 0.24261398698137834 atm
PO2 : 0.1905946372855047 atm
###########
I : 0.6
E : 2.923407810775032 V
FC Efficiency : 0.4040118444230801
FC Power : 1.8907754319000147 W
FC Voltage : 3.1512923865000246 V
PH2 : 0.19710049042472996 atm
PH2O : 0.2425966933860498 atm
PO2 : 0.1905867044473064 atm
###########
I : 0.7
E : 2.923406272883388 V
FC Efficiency : 0.4030287270042349
FC Power : 2.2005368494431226 W
FC Voltage : 3.1436240706330323 V
PH2 : 0.19708644004311557 atm
PH2O : 0.24257939979072127 atm
PO2 : 0.19057877160910808 atm
###########
I : 0.8
E : 2.9234047349277277 V
FC Efficiency : 0.4021718894938075
FC Power : 2.509552590441359 W
FC Voltage : 3.1369407380516985 V
PH2 : 0.19707238966150117 atm
PH2O : 0.24256210619539273 atm
PO2 : 0.1905708387709098 atm
###########
I : 0.9
E : 2.9234031969080454 V
FC Efficiency : 0.4014115005665013
FC Power : 2.81790873397684 W
FC Voltage : 3.1310097044187106 V
PH2 : 0.19705833927988675 atm
PH2O : 0.24254481260006414 atm
PO2 : 0.19056290593271147 atm
###########
I : 1.0
E : 2.9234016588243374 V
FC Efficiency : 0.40072719160282416
FC Power : 3.1256720945020287 W
FC Voltage : 3.1256720945020287 V
PH2 : 0.19704428889827239 atm
PH2O : 0.2425275190047356 atm
PO2 : 0.1905549730945132 atm
###########
I : 1.1
E : 2.9234001206765963 V
FC Efficiency : 0.40010443449551725
FC Power : 3.4328960479715387 W
FC Voltage : 3.1208145890650347 V
PH2 : 0.197030238516658 atm
PH2O : 0.24251022540940706 atm
PO2 : 0.19054704025631486 atm
###########
I : 1.2
E : 2.9233985824648183 V
FC Efficiency : 0.39953250222749515
FC Power : 3.7396242208493544 W
FC Voltage : 3.116353517374462 V
PH2 : 0.1970161881350436 atm
PH2O : 0.24249293181407852 atm
PO2 : 0.19053910741811658 atm
###########
I : 1.3
E : 2.923397044188998 V
FC Efficiency : 0.3990032485837277
FC Power : 4.045892940639 W
FC Voltage : 3.1122253389530767 V
PH2 : 0.19700213775342923 atm
PH2O : 0.24247563821874998 atm
PO2 : 0.19053117457991825 atm
###########
I : 1.4
E : 2.923395505849129 V
FC Efficiency : 0.3985103413824903
FC Power : 4.351732927896794 W
FC Voltage : 3.1083806627834245 V
PH2 : 0.19698808737181484 atm
PH2O : 0.24245834462342142 atm
PO2 : 0.19052324174171997 atm
###########
I : 1.5
E : 2.923393967445207 V
FC Efficiency : 0.3980487608857143
FC Power : 4.657170502362857 W
FC Voltage : 3.1047803349085714 V
PH2 : 0.19697403699020044 atm
PH2O : 0.24244105102809288 atm
PO2 : 0.19051530890352164 atm
###########
I : 1.6
E : 2.923392428977226 V
FC Efficiency : 0.39761446042126253
FC Power : 4.962228466057358 W
FC Voltage : 3.101392791285848 V
PH2 : 0.19695998660858605 atm
PH2O : 0.24242375743276434 atm
PO2 : 0.19050737606532336 atm
###########
I : 1.7
E : 2.9233908904451815 V
FC Efficiency : 0.3972041300730298
FC Power : 5.2669267647683755 W
FC Voltage : 3.098192214569633 V
PH2 : 0.19694593622697168 atm
PH2O : 0.2424064638374358 atm
PO2 : 0.19049944322712503 atm
###########
I : 1.8
E : 2.9233893518490675 V
FC Efficiency : 0.39681502801851076
FC Power : 5.571282993379892 W
FC Voltage : 3.0951572185443843 V
PH2 : 0.19693188584535729 atm
PH2O : 0.24238917024210727 atm
PO2 : 0.19049151038892673 atm
###########
I : 1.9
E : 2.9233878131888784 V
FC Efficiency : 0.3964448575287326
FC Power : 5.875312788575817 W
FC Voltage : 3.0922698887241142 V
PH2 : 0.1969178354637429 atm
PH2O : 0.24237187664677873 atm
PO2 : 0.19048357755072845 atm
###########
I : 2.0
E : 2.9233862744646095 V
FC Efficiency : 0.3960916755547374
FC Power : 6.1790301386539035 W
FC Voltage : 3.0895150693269517 V
PH2 : 0.19690378508212852 atm
PH2O : 0.2423545830514502 atm
PO2 : 0.19047564471253012 atm
###########
I : 2.1
E : 2.923384735676255 V
FC Efficiency : 0.39575382364054146
FC Power : 6.482447631232071 W
FC Voltage : 3.086879824396224 V
PH2 : 0.19688973470051413 atm
PH2O : 0.24233728945612165 atm
PO2 : 0.19046771187433184 atm
###########
I : 2.2
E : 2.92338319682381 V
FC Efficiency : 0.3954298749226794
FC Power : 6.78557665367318 W
FC Voltage : 3.0843530243968997 V
PH2 : 0.19687568431889974 atm
PH2O : 0.2423199958607931 atm
PO2 : 0.1904597790361335 atm
###########
I : 2.3
E : 2.923381657907269 V
FC Efficiency : 0.39511859292081414
FC Power : 7.088427556999405 W
FC Voltage : 3.0819250247823504 V
PH2 : 0.19686163393728537 atm
PH2O : 0.24230270226546458 atm
PO2 : 0.19045184619793523 atm
###########
I : 2.4
E : 2.9233801189266266 V
FC Efficiency : 0.39481889910524637
FC Power : 7.391009791250212 W
FC Voltage : 3.079587413020922 V
PH2 : 0.19684758355567097 atm
PH2O : 0.242285408670136 atm
PO2 : 0.1904439133597369 atm
###########
I : 2.5
E : 2.923378579881877 V
FC Efficiency : 0.39452984708947947
FC Power : 7.693332018244849 W
FC Voltage : 3.07733280729794 V
PH2 : 0.19683353317405658 atm
PH2O : 0.24226811507480747 atm
PO2 : 0.19043598052153862 atm
###########
I : 2.6
E : 2.923377040773016 V
FC Efficiency : 0.39425060188740335
FC Power : 7.995402206276542 W
FC Voltage : 3.0751546947217467 V
PH2 : 0.19681948279244216 atm
PH2O : 0.2422508214794789 atm
PO2 : 0.1904280476833403 atm
###########
I : 2.7
E : 2.923375501600037 V
FC Efficiency : 0.3939804230873111
FC Power : 8.297227710218774 W
FC Voltage : 3.073047300081027 V
PH2 : 0.19680543241082776 atm
PH2O : 0.24223352788415034 atm
PO2 : 0.190420114845142 atm
###########
I : 2.8
E : 2.923373962362936 V
FC Efficiency : 0.3937186510874208
FC Power : 8.59881533974927 W
FC Voltage : 3.0710054784818825 V
PH2 : 0.1967913820292134 atm
PH2O : 0.2422162342888218 atm
PO2 : 0.19041218200694368 atm
###########
I : 2.9
E : 2.9233724230617057 V
FC Efficiency : 0.3934646957478549
FC Power : 8.900171417816479 W
FC Voltage : 3.0690246268332686 V
PH2 : 0.196777331647599 atm
PH2O : 0.24219894069349326 atm
PO2 : 0.1904042491687454 atm
###########
I : 3.0
E : 2.923370883696343 V
FC Efficiency : 0.39321802696722546
FC Power : 9.201301831033076 W
FC Voltage : 3.0671006103443585 V
PH2 : 0.1967632812659846 atm
PH2O : 0.24218164709816473 atm
PO2 : 0.19039631633054707 atm
###########
I : 3.1
E : 2.9233693442668414 V
FC Efficiency : 0.39297816680494896
FC Power : 9.502212073343667 W
FC Voltage : 3.0652297010786023 V
PH2 : 0.19674923088437024 atm
PH2O : 0.2421643535028362 atm
PO2 : 0.1903883834923488 atm
###########
I : 3.2
E : 2.9233678047731946 V
FC Efficiency : 0.39274468285467545
FC Power : 9.8029072840527 W
FC Voltage : 3.0634085262664685 V
PH2 : 0.19673518050275585 atm
PH2O : 0.24214705990750765 atm
PO2 : 0.19038045065415046 atm
###########
I : 3.3
E : 2.9233662652153996 V
FC Efficiency : 0.3925171826377131
FC Power : 10.103392281094736 W
FC Voltage : 3.0616340245741624 V
PH2 : 0.19672113012114145 atm
PH2O : 0.2421297663121791 atm
PO2 : 0.19037251781595219 atm
###########
I : 3.4
E : 2.923364725593449 V
FC Efficiency : 0.39229530883366054
FC Power : 10.403671590268678 W
FC Voltage : 3.059903408902552 V
PH2 : 0.19670707973952706 atm
PH2O : 0.24211247271685057 atm
PO2 : 0.19036458497775385 atm
###########
I : 3.5
E : 2.923363185907339 V
FC Efficiency : 0.39207873520256487
FC Power : 10.703749471030022 W
FC Voltage : 3.0582141345800062 V
PH2 : 0.1966930293579127 atm
PH2O : 0.24209517912152204 atm
PO2 : 0.19035665213955555 atm
###########
I : 3.6
E : 2.923361646157063 V
FC Efficiency : 0.3918671630816706
FC Power : 11.003629939333312 W
FC Voltage : 3.0565638720370307 V
PH2 : 0.1966789789762983 atm
PH2O : 0.2420778855261935 atm
PO2 : 0.19034871930135727 atm
###########
I : 3.7
E : 2.923360106342616 V
FC Efficiency : 0.3916603183622587
FC Power : 11.303316787934786 W
FC Voltage : 3.054950483225618 V
PH2 : 0.1966649285946839 atm
PH2O : 0.24206059193086493 atm
PO2 : 0.19034078646315894 atm
###########
I : 3.8
E : 2.9233585664639925 V
FC Efficiency : 0.3914579488697281
FC Power : 11.602813604498742 W
FC Voltage : 3.0533720011838796 V
PH2 : 0.19665087821306954 atm
PH2O : 0.2420432983355364 atm
PO2 : 0.19033285362496066 atm
###########
I : 3.9
E : 2.9233570265211877 V
FC Efficiency : 0.3912598220840501
FC Power : 11.902123787796803 W
FC Voltage : 3.051826612255591 V
PH2 : 0.19663682783145514 atm
PH2O : 0.24202600474020786 atm
PO2 : 0.19032492078676233 atm
###########
Done!
>>> Padulles_Hauer_Data=Dynamic_Analysis(InputMethod={}, TestMode=True)
###########
Padulles-Hauer-Model Simulation
###########
Analyzing . . .
[Error] Padulles-Hauer Dynamic Simulation Failed!(Check Your Inputs)
>>> qH2_Calc(qMethanol=None,CV=2,t1=2,t2=2)
[Error] qH2 Calculation Failed (qMethanol:None, CV:2, t1:2, t2:2)
>>> cov.stop()
>>> cov.save()

'''